/**************************************************************************************************
	Developed by: the Colorado Health Institute (CHI)
	Contact Information: 
		Glenn Goodrich
		303-831-4200 x225
		goodrichg@coloradohealthinstitute.org

	The 2009 dentist (non-rural) public use file was created with a 64-bit  
	version of SAS 9.2 on a 64-bit MS Windows operating system. If this data file will be 
	used with a 32-bit version of SAS 9.2 or earlier, the data file needs to be reassigned, 
	through a DATA STEP, so that it can subsequently assign the SAS formats correctly.

	The following code will execute the necessary DATA STEP described above and then assign 
	the SAS formats to the variables included in the dentist public use file. 

	INPUT: uden09_puf.sas7bdat (64-bit SAS 9.2 data file from CHI)
	OUTPUT: a data file compatible with the user's version of SAS, with its associated SAS formats 

	NOTATION:
		>> USER INPUT <<;
		indicates all places in the beginning of the code where the user 
		should input information.
	
***************************************************************************************************/
options mprint mlogic symbolgen;
%global filename lib fmtlib;

************************** USER INPUT REQUIRED FOR THIS SECTION ONLY *******************************;

*>> USER INPUT <<;
* INSTRUCTIONS: provide a name for the SAS library associated with the location of the final 
* version of the data file
* (Example: lib = Survey);
%let lib = ;

*>> USER INPUT <<;
* INSTRUCTIONS: directory pathname for where the final version of the data file will be stored
* (Example: "C:\MyData");
libname &lib. "";

*>> USER INPUT <<;
* INSTRUCTIONS: name for FINAL version of the data file (it must have a different filename 
* than the CHI version if it will be stored in the SAME directory)
* (Example: filename = SurveyData);
%let filename = ;


*>> USER INPUT <<;
* INSTRUCTIONS: directory path name for where the CHI version of the Research data file is located
* (Example: "C:\MyData\CHI");
libname LIB1 "";

*>> USER INPUT <<;
* INSTRUCTIONS: name for SAS library where the formats with be stored 
* (Example: fmtlib = denfmt);
%let fmtlib = ;

*>> USER INPUT <<;
* INSTRUCTIONS: directory pathname for where format catalog will be stored
* (Example: "C:\MyData\Formats");
libname &fmtlib. "";

***************************************** END USER INPUT ******************************************
***************************************************************************************************;


options fmtsearch=(&fmtlib.);

* this DATA STEP will restructure the SAS data file to be compatible with user's version of SAS;
data &lib..&filename.; set lib1.uden09_puf; run;
proc format library=&fmtlib.;
value ud09_agegrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1='34 years or younger'
2='35-44 years'
3='45-54 years'
4='55 or older'
;
value ud09_brthgrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="On or before 1954"
2="1955-1964"
3="1965-1974"
4="1975 or after"
;
value ud09_charcrb
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="$2,500 or less"
2="$2,501 to $5,000"
3="$5,001 to $10,000"
4="$10,001 to $25,000"
5="$25,001 or more"
6="Do not know"
;
value ud09_ftchr
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="None"
2="1 FT chair side assistant"
3="2 FT chair side assistants"
4="3 or more FT chair side assistants"
;
value ud09_ftdent
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="None"
2="1 FT dentist"
3="2 FT dentists"
4="3 or more FT dentists"
;
value ud09_ftdh
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="None"
2="1 FT dental hygienist"
3="2 FT dental hygienists"
4="3 or more FT dental hygienists"
;
value ud09_gend
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="Male"
0="Female"
;
value ud09_gradyrgrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="1983 or before"
2="1984-1993"
3="1994-2003"
4="2004 or later"
;
value ud09_grage
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0-25 years"
2="26-35 years"
3="36 years or more"
;
value ud09_grstgrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
0="Not Colorado"
1="Colorado"
;
value ud09_grwup
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="Rural"
2="Suburban"
3="Urban"
;
value ud09_hrdircr
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0-24 hours"
2="25-32 hours"
3="33 hours or more"
;
value ud09_impb
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
0="Not Important or indifferent, (3,4,5)"
1="Very Important/Important (1,2)"
2="N/A"
;
value ud09_inad
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
0="Adequate or indifferent, (1,2,3)"
1="Inadequate (4,5)"
2="N/A"
;
value ud09_LGTHSV_grp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0-5 years"
2="6-10 years"
3="11-20 years"
4="21 years or more"
;
value ud09_pctadlt
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0-10 percent"
2="11-40 percent"
3="41-50 percent"
4="51-60 percent"
5="61-70 percent"
6="71-100 percent"
;
value ud09_pctchil
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0-10 percent"
2="11-20 percent"
3="21-50 percent"
4="51-100 percent"
;
value ud09_pctinf
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0 or none"
2="1 to 5 percent"
3="6 percent or more"
;
value ud09_pctoldadlt
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0 percent"
2="1-10 percent"
3="11-20 percent"
4="21-30 percent"
5="31-100 percent"
;
value ud09_pracyrcogrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0-5 years"
2="6-10 years"
3="11-20 years"
4="21-25 years"
5="26-30 years"
6="31 years"
;
value ud09_prfhrs
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0-24 hours"
2="25-32 hours"
3="33-40 hours"
4="41 hours or more"
;
value ud09_prprac
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
0="Prepared or indifferent, (1,2,3)"
1="Not prepared (4,5)"
;
value ud09_prstatb
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="Fulltime dentist actively seeing patients"
2="Part-time dentist actively seeing patients"
3="Retired, not seeing patients, or out of state"
;
value ud09_ptchr
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="None"
2="1 PT chair side assistant"
3="2 or more PT chair side assistants"
;
value ud09_ptdent
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="None"
2="1 or more PT dentists"
;
value ud09_ptdh
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="None"
2="1 PT dental hygienist"
3="2 PT dental hygienists"
4="3 or more PT dental hygienists"
;
value ud09_racegrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
0="Non-white"
1="White"
;
value ud09_rcrtdh
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="It is easy to recruit dental hygienists in my practice"
2="It is difficult to recruit dental hygienists in my practice"
3="I am not currently recruiting a dental hygienist"
;
value ud09_rtndh
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="I am not currently employing or contracting with a dental hygienist"
2="It is easy to retain dental hygienists in my practice"
3="It is difficult to retain dental hygienists in my practice"
;
value ud09_settingb
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="Solo, private practice"
2="Dental group in private practice"
3="Public health dept/agency, or Community Health center"
;
value ud09_spanish
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
0="Other language, not Spanish"
1="Spanish"
;
value ud09_visgrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0-1000 visits"
2="1001-1499 visits"
3="1500-2000 visits"
4="2001-3000 visits"
5="3000+ visits"
;
value ud09_yn
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
0="No"
1="Yes"
2="N/A"
;
value ud09_yrsncegradgrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0-5 years"
2="6-15 years"
3="16-25 years"
4="26-35 years"
5="36 years or more"
;
run;
proc datasets library = &lib.;
	modify &filename.;
	format age_grp UD09_AGEGRP.;
	format birth_yr_grp UD09_BRTHGRP.;
	format charity_grp UD09_CHARCRB.;
	format FT_DENCHR_ASST_grp UD09_FTCHR.;
	format ft_dent_office_grp UD09_FTDENT.;
	format ft_denhyg_grp UD09_FTDH.;
	format GENDER UD09_GEND.;
	format grad_year_grp UD09_GRADYRGRP.;
	format grad_age_grp UD09_GRAGE.;
	format grad_state_grp UD09_GRSTGRP.;
	format GREWUP_LOCATION UD09_GRWUP.;
	format HRS08_DIRCARE_grp UD09_HRDIRCR.;
	format REJECTMDCD_REIMBLOW_grp REJECTMDCD_TIMECONS_grp REJECTMDCD_NOSHOW_grp
	REJECTMDCD_PTCOMPL_grp INCRMDCD_REIMB_grp EXPNDMDCD_LWINCADLT_grp
	ENSURE_ACC_DINS_grp LWLIAB_VOLCARE_grp LOANFGV_UNDERSV_grp UD09_IMPB.;
	format EDCARE_PREGNANT_grp EDCARE_INFANT_grp EDCARE_CHILDREN_grp EDCARE_DISAB_grp
	EDCARE_BEHAVE_grp EDCARE_SETUP_PR_grp EDCARE_MGMT_grp EDCARE_WORKWITH_grp
	EDCARE_ENDO_grp EDCARE_ORSURG_grp EDCARE_ORTHO_grp EDCARE_PERIO_grp
	CLIN_PREGNANT_grp CLIN_INFANT_grp CLIN_CHILDREN_grp CLIN_DISAB_grp
	CLIN_BEHAVE_grp CLIN_PREVENTIVE_grp CLIN_WORKWITH_grp CLIN_ENDO_grp
	CLIN_ORSURG_grp CLIN_ORTHO_grp CLIN_PERIO_grp UD09_INAD.;
	format LGTH_SVC_YR_PRIMARY_grp UD09_LGTHSV_GRP.;
	format PCTCARE_ADULT_grp UD09_PCTADLT.;
	format PCTCARE_CHILDREN_grp UD09_PCTCHIL.;
	format PCTCARE_INFANT_grp UD09_PCTINF.;
	format PCTCARE_OLDADULT_grp UD09_PCTOLDADLT.;
	format PRACYR_CO_grp UD09_PRACYRCOGRP.;
	format HRS08_TOTPROF_grp UD09_PRFHRS.;
	format PREPARE_MGMT_DENT_grp UD09_PRPRAC.;
	format employ_status_grp UD09_PRSTATB.;
	format PT_DENCHR_ASST_grp UD09_PTCHR.;
	format pt_dent_office_grp UD09_PTDENT.;
	format pt_denhyg_grp UD09_PTDH.;
	format race_grp UD09_RACEGRP.;
	format recruitdh UD09_RCRTDH.;
	format retaindh UD09_RTNDH.;
	format setting_grp UD09_SETTINGB.;
	format lang_spanish UD09_SPANISH.;
	format visits_2008_grp UD09_VISGRP.;
	format ada_cert ORTHODON PEDIATRIC prv_endo prv_ormaxpath prv_ormaxrad prv_ormaxsurg
	prv_orthodontics prv_pediatrics prv_periodontics prv_prosthodontics COMM_QUAL_LIFE
	COMM_RECREATION comm_salary comm_jnlrgprc comm_boughtest COMM_OTHER
	SERVE_SFS_INC ACCEPT_MDCAID ACCEPT_NEW_MDCAID ACCEPT_CHPP_PAY ACCEPT_NEW_CHPP_PAY
	ACCEPT_DELTA ACCEPT_NEW_DELTA LANG_OTHENG LEAVE_NEXT12MO COLLAB_OTHERS
	CHALLENGE_NONE CHALLENGE_LOWVOL CHALLENGE_LOWCOLLECT CHALLENGE_INSREIMB
	CHALLENGE_PHYDEM CHALLENGE_MGMT CHALLENGE_OTHER UD09_YN.;
	format grad_numyrs_grp UD09_YRSNCEGRADGRP.;
quit;
